@@ -1,6 +1,6 @@
 package Storm::Query::Delete;
 {
-  $Storm::Query::Delete::VERSION = '0.200';
+  $Storm::Query::Delete::VERSION = '0.240';
 }
 
 use Moose;
@@ -12,7 +12,7 @@ with 'Storm::Role::Query::IsExecutable';
 
 sub _sql {
     my ( $self ) = @_;
-    my $table = $self->class->meta->storm_table->sql;
+    my $table = $self->orm->table( $self->class );
     my $column = $self->class->meta->primary_key->column->sql;
     return  qq[DELETE FROM $table WHERE $column = ?];
 }
